from distutils.core import setup

setup(
    name = 'waple',
    version = '1.1.0',
    py_modules = ['waple'],
    author = 'waple',
    author_email = 'waple0820@gmai.com',
    url = 'www.headfirstlabs.com',
    description = 'A sample',
    )
